Support derivative term in PID algorithm and support to set cycle interval time from fan table

1. Support to calculate derivative term in PID algorithm.
2. Add two properties: cycleIntervalTimeMS and updateThermalsTimeMS
in fan table that could be used to decide "time interval of PID control loop"
and "time interval to update thermals' cached value".

Tested:

- PID algorithm:
    1. Check pid-control-service could calculate output PWM
       according to the fan table.

	[Test log]
        root@greatlakes:~# systemctl status phosphor-pid-control -l
        * phosphor-pid-control.service - Phosphor-Pid-Control Margin-based Fan Control Daemon
             Loaded: loaded (/lib/systemd/system/phosphor-pid-control.service; enabled; preset: enabled)
             Active: active (running) since Fri 2018-03-09 05:09:35 PST; 1min 47s ago
           Main PID: 3105 (swampd)
             CGroup: /system.slice/phosphor-pid-control.service
                     `-3105 /usr/bin/swampd -c /usr/share/entity-manager/configurations/fan-table.json
        ...
        Mar 09 05:10:29 greatlakes phosphor-pid-control[3105]: PID Zone 1 max SetPoint 3.75 requested by
        PID_NIC_SENSOR_TEMP BMC_SENSOR_FAN0_TACH BMC_SENSOR_FAN2_TACH BMC_SENSOR_FAN4_TACH BMC_SENSOR_FAN6_TACH

- Cycle interval time:
    1. Set cycleIntervalTimeMS and updateThermalsTimeMS
       to 1000 ms in fan table
    2. Check service would update thermal every second from debug log.

	[Test log]
        root@greatlakes:~# journalctl -u phosphor-pid-control --since "Mar 09 04:52:16"
        Mar 09 04:52:16 greatlakes systemd[1]: Started Phosphor-Pid-Control Margin-based Fan Control Daemon.
        ...
        Mar 09 04:53:28 greatlakes phosphor-pid-control[2795]: processThermals
        Mar 09 04:53:28 greatlakes phosphor-pid-control[2795]: processFans
        Mar 09 04:53:29 greatlakes phosphor-pid-control[2795]: processThermals
        Mar 09 04:53:29 greatlakes phosphor-pid-control[2795]: processFans
        Mar 09 04:53:30 greatlakes phosphor-pid-control[2795]: processThermals
        Mar 09 04:53:30 greatlakes phosphor-pid-control[2795]: processFans

Change-Id: I04e1b440603c3ad66a1e26c96451992785da6fe6
Signed-off-by: Bonnie Lo <Bonnie_Lo@wiwynn.com>
diff --git a/pid/pidloop.hpp b/pid/pidloop.hpp
index f9b78b3..0a143e7 100644
--- a/pid/pidloop.hpp
+++ b/pid/pidloop.hpp
@@ -17,11 +17,11 @@
  * @param[in] isCanceling - bool ptr to indicate whether pidControlLoop is being
  * canceled.
  * @param[in] first - boolean to denote if initialization needs to be run.
  * @param[in] ms100cnt - loop timer counter.
  */
 void pidControlLoop(std::shared_ptr<ZoneInterface> zone,
                     std::shared_ptr<boost::asio::steady_timer> timer,
                     const bool* isCanceling, bool first = true,
-                    int ms100cnt = 0);
+                    uint64_t cycleCnt = 0);
 
 } // namespace pid_control
@@ -17,11 +17,11 @@
  * canceled.
  * @param[in] first - boolean to denote if initialization needs to be run.
- * @param[in] ms100cnt - loop timer counter.
+ * @param[in] cycleCnt - loop timer counter.
  */
 void pidControlLoop(std::shared_ptr<ZoneInterface> zone,